fix collapsing problem with templates (templates would be expanded and
[lhc/web/wiklou.git] / index.php
index 57875af..d2ec9fc 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,44 +1,43 @@
 <?php
+
 # Main wiki script; see design.doc
 #
 $wgRequestTime = microtime();
 
 unset( $IP );
-ini_set( "allow_url_fopen", 0 ); # For security...
+@ini_set( "allow_url_fopen", 0 ); # For security...
 if(!file_exists("LocalSettings.php")) {
        die( "You'll have to <a href='config/index.php'>set the wiki up</a> first!" );
 }
-include_once( "./LocalSettings.php" );
-
-if( $wgSitename == "MediaWiki" ) {
-       die( "You must set the site name in \$wgSitename before installation.\n\n" );
-}
-
-# Windows requires ';' as separator, ':' for Unix
-$sep = strchr( $include_path = ini_get( "include_path" ), ";" ) ? ";" : ":";
-ini_set( "include_path", "$IP$sep$include_path" );
 
-include_once( "Setup.php" );
+define( "MEDIAWIKI", true );
+require_once( "./LocalSettings.php" );
+require_once( "includes/Setup.php" );
 
 wfProfileIn( "main-misc-setup" );
 OutputPage::setEncodings(); # Not really used yet
 
 # Query string fields
-#
-global $action, $title, $search, $go, $target, $printable;
-global $returnto, $diff, $oldid, $curid;
+$action = $wgRequest->getVal( "action", "view" );
+
+if( isset( $_SERVER['PATH_INFO'] ) && $wgUsePathInfo ) {
+       $title = substr( $_SERVER['PATH_INFO'], 1 );
+} else {
+       $title = $wgRequest->getVal( "title" );
+}
 
 # Placeholders in case of DB error
 $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
 $wgArticle = new Article($wgTitle);
 
 $action = strtolower( trim( $action ) );
-if ( "" == $action ) { $action = "view"; }
-if ( "yes" == $printable ) { $wgOut->setPrintable(); }
+if ($wgRequest->getVal( "printable" ) == "yes") {
+       $wgOut->setPrintable();
+}
 
 if ( "" == $title && "delete" != $action ) {
        $wgTitle = Title::newFromText( wfMsg( "mainpage" ) );
-} elseif ( $curid ) {
+} elseif ( $curid = $wgRequest->getInt( 'curid' ) ) {
        # URLs like this are generated by RC, because rc_title isn't always accurate
        $wgTitle = Title::newFromID( $curid );
 } else {
@@ -46,38 +45,47 @@ if ( "" == $title && "delete" != $action ) {
 }
 wfProfileOut( "main-misc-setup" );
 
-# If the user is not logged in, the Namespace:title of the article must be in the Read array in
-#  order for the user to see it.
-if ( !$wgUser->getID() && is_array( $wgWhitelistRead ) && $wgTitle) {
-       if ( !in_array( $wgLang->getNsText( $wgTitle->getNamespace() ) . ":" . $wgTitle->getDBkey(), $wgWhitelistRead ) ) {
-               $wgOut->loginToUse();
-               $wgOut->output();
-               exit;
-       }
+# If the user is not logged in, the Namespace:title of the article must be in
+# the Read array in order for the user to see it. (We have to check here to
+# catch special pages etc. We check again in Article::view())
+if ( !$wgTitle->userCanRead() ) {
+       $wgOut->loginToUse();
+       $wgOut->output();
+       exit;
 }
 
-if ( "" != $search ) {
-       if( isset($_REQUEST['fulltext']) ) {
+if ( $search = $wgRequest->getText( 'search' ) ) {
+       $wgTitle = Title::makeTitle( NS_SPECIAL, "Search" );
+       if( $wgRequest->getVal( 'fulltext' ) ) {
                wfSearch( $search );
        } else {
                wfGo( $search );
        }
-} else if( !$wgTitle or $wgTitle->getInterwiki() != "" or $wgTitle->getDBkey() == "" ) {
+} else if( !$wgTitle or $wgTitle->getDBkey() == "" ) {
        $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
        $wgOut->errorpage( "badtitle", "badtitletext" );
+} else if ( $wgTitle->getInterwiki() != "" ) {
+       $url = $wgTitle->getFullURL();
+       # Check for a redirect loop
+       if ( !preg_match( "/^" . preg_quote( $wgServer ) . "/", $url ) && $wgTitle->isLocal() ) {
+               $wgOut->redirect( $url );
+       } else {
+               $wgTitle = Title::newFromText( wfMsg( "badtitle" ) );
+               $wgOut->errorpage( "badtitle", "badtitletext" );
+       }
 } else if ( ( $action == "view" ) && $wgTitle->getPrefixedDBKey() != $title ) {
        /* redirect to canonical url, make it a 301 to allow caching */
-       $wgOut->redirect( wfLocalUrl( $wgTitle->getPrefixedURL() ), '301');
+       $wgOut->redirect( $wgTitle->getFullURL(), '301');
 } else if ( Namespace::getSpecial() == $wgTitle->getNamespace() ) {
        wfSpecialPage();
 } else {
        if ( Namespace::getMedia() == $wgTitle->getNamespace() ) {
                $wgTitle = Title::makeTitle( Namespace::getImage(), $wgTitle->getDBkey() );
-       }       
-       
+       }
+
        switch( $wgTitle->getNamespace() ) {
-       case 6:
-               include_once( "ImagePage.php" );
+       case NS_IMAGE:
+               require_once( "includes/ImagePage.php" );
                $wgArticle = new ImagePage( $wgTitle );
                break;
        default:
@@ -87,6 +95,9 @@ if ( "" != $search ) {
        wfQuery("BEGIN", DB_WRITE);
        switch( $action ) {
                case "view":
+                       $wgOut->setSquidMaxage( $wgSquidMaxage );
+                       $wgArticle->view();
+                       break;
                case "watch":
                case "unwatch":
                case "delete":
@@ -99,20 +110,49 @@ if ( "" != $search ) {
                case "print":
                        $wgArticle->view();
                        break;
+               case "dublincore":
+                       if( !$wgEnableDublinCoreRdf ) {
+                               wfHttpError( 403, "Forbidden", wfMsg( "nodublincore" ) );
+                       } else {
+                               require_once( "includes/Metadata.php" );
+                               wfDublinCoreRdf( $wgArticle );
+                       }
+                       break;
+               case "creativecommons":
+                       if( !$wgEnableCreativeCommonsRdf ) {
+                               wfHttpError( 403, "Forbidden", wfMsg("nocreativecommons") );
+                       } else {
+                               require_once( "includes/Metadata.php" );
+                               wfCreativeCommonsRdf( $wgArticle );
+                       }
+                       break;
                case "edit":
                case "submit":
-                       if( !$wgCommandLineMode && !isset( $_COOKIE[ini_get("session.name")] ) ) {
+                       if( !$wgCommandLineMode && !$wgRequest->checkSessionCookie() ) {
                                User::SetupSession();
                        }
-                       include_once( "EditPage.php" );
+                       require_once( "includes/EditPage.php" );
                        $editor = new EditPage( $wgArticle );
                        $editor->$action();
                        break;
                case "history":
-                       include_once( "PageHistory.php" );
+                       if ($_SERVER["REQUEST_URI"] == $wgTitle->getInternalURL('action=history')) {
+                               $wgOut->setSquidMaxage( $wgSquidMaxage );
+                       }
+                       require_once( "includes/PageHistory.php" );
                        $history = new PageHistory( $wgArticle );
                        $history->history();
                        break;
+               case "raw":
+                       require_once( "includes/RawPage.php" );
+                       $raw = new RawPage( $wgArticle );
+                       $raw->view();
+                       break;
+               case "purge":
+                       wfPurgeSquidServers(array($wgTitle->getInternalURL()));
+                       $wgOut->setSquidMaxage( $wgSquidMaxage );
+                       $wgArticle->view();
+                       break;
                default:
                        $wgOut->errorpage( "nosuchaction", "nosuchactiontext" );
        }
@@ -120,6 +160,7 @@ if ( "" != $search ) {
 }
 
 $wgOut->output();
+
 foreach ( $wgDeferredUpdateList as $up ) { $up->doUpdate(); }
 logProfilingData();
 wfDebug( "Request ended normally\n" );